==> haskell-time-locale-compat-0.1.1.4-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-time-locale-compat.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: time-locale-compat
version: 0.1.1.4
id: time-locale-compat-0.1.1.4-4FewSj9xNz5KwikEo4XZpe
key: time-locale-compat-0.1.1.4-4FewSj9xNz5KwikEo4XZpe
license: BSD3
copyright: Copyright (c) 2014-2018 Kei Hibino
maintainer: ex8k.hibino@gmail.com
homepage: https://github.com/khibino/haskell-time-locale-compat
synopsis: Compatibile module for time-format locale
description:
    This package contains wrapped name module for time-format locale between old-locale and time-1.5.
category: System
author: Kei Hibino
exposed: True
indefinite: False
exposed-modules:
    Data.Time.Locale.Compat
abi: f89b9bf78521b39585bc3f18eca5f646
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/time-locale-compat-0.1.1.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/time-locale-compat-0.1.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/time-locale-compat-0.1.1.4
hs-libraries: HStime-locale-compat-0.1.1.4-4FewSj9xNz5KwikEo4XZpe
depends:
    base-4.10.1.0 time-1.8.0.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
haddock-interfaces: /usr/share/doc/haskell-time-locale-compat/html/time-locale-compat.haddock
haddock-html: /usr/share/doc/haskell-time-locale-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-time-locale-compat-0.1.1.4-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-time-locale-compat.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: time-locale-compat
version: 0.1.1.4
id: time-locale-compat-0.1.1.4-7wM80GF7eQsF3fUTGOdEvb
key: time-locale-compat-0.1.1.4-7wM80GF7eQsF3fUTGOdEvb
license: BSD-3-Clause
copyright: Copyright (c) 2014-2018 Kei Hibino
maintainer: ex8k.hibino@gmail.com
author: Kei Hibino
homepage: https://github.com/khibino/haskell-time-locale-compat
synopsis: Compatibile module for time-format locale
description:
    This package contains wrapped name module for time-format locale between old-locale and time-1.5.
category: System
abi: 87c3e02b63d10c8290e7f2f894b7a341
exposed: True
exposed-modules:
    Data.Time.Locale.Compat
import-dirs: /usr/lib/ghc-8.4.3/site-local/time-locale-compat-0.1.1.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/time-locale-compat-0.1.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/time-locale-compat-0.1.1.4
hs-libraries: HStime-locale-compat-0.1.1.4-7wM80GF7eQsF3fUTGOdEvb
depends:
    base-4.11.1.0 time-1.8.0.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
haddock-interfaces: /usr/share/doc/haskell-time-locale-compat/html/time-locale-compat.haddock
haddock-html: /usr/share/doc/haskell-time-locale-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
